"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
/**
 * import文のrootからのパスを求める
 */
exports.default = (importPath, relativeFilePath) => {
    // { [importAlias: string]: OriginalPath }
    const importAliasMap = {};
    // Load tsconfig option
    // MEMO: tscとか使って簡単に読める方法がありそう
    try {
        const tsConfigFile = fs_1.default.readFileSync(path_1.default.join(process.cwd(), '/tsconfig.json'), 'utf-8');
        // Exists ts config
        const tsConfig = JSON.parse(tsConfigFile);
        if (tsConfig.compilerOptions && tsConfig.compilerOptions.paths) {
            Object.keys(tsConfig.compilerOptions.paths).forEach((key) => {
                // FIXME: このlint ruleではimport先が存在するかチェックしておらず、複数のパスから正しい方を選択できないため[0]固定
                importAliasMap[key] = tsConfig.compilerOptions.baseUrl ? path_1.default.join(tsConfig.compilerOptions.baseUrl, tsConfig.compilerOptions.paths[key][0]) : tsConfig.compilerOptions.paths[key][0];
            });
        }
    }
    catch (error) {
        // DO NOTHING
    }
    if (relativeFilePath && (importPath.startsWith('./') || importPath.startsWith('../'))) {
        importPath = path_1.default.join(path_1.default.dirname(relativeFilePath), importPath);
    }
    return Object.keys(importAliasMap).reduce((resolvedImportPath, key) => {
        // FIXME: use glob module instead of replace('*')
        return resolvedImportPath.replace(key.replace('*', ''), importAliasMap[key].replace('*', ''));
    }, importPath);
};
